<?php
/*
Plugin Name: Auto Thickbox Plus
Plugin URI: http://attosoft.info/blog/en/auto-thickbox-plus/
Description: Overlays linked image, inline, iFrame and AJAX content on the page in simple & fast effects. (improved version of Auto Thickbox plugin)
Author: attosoft
Version: 0.6
Author URI: http://attosoft.info/en/
Text Domain: auto-thickbox
Domain Path: /lang
*/

/*  Copyright 2010-2012 attosoft (contact@attosoft.info)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/* This plugin is mainly based on Auto Thickbox Plugin by Denis de Bernardy.
   http://www.semiologic.com/software/auto-thickbox/
*/

define('AUTO_THICKBOX_PLUS_VERSION', '0.6');

load_plugin_textdomain('auto-thickbox', false, dirname(plugin_basename(__FILE__)) . '/lang');


/**
 * auto_thickbox
 *
 * @package Auto Thickbox
 **/

class auto_thickbox {
	/**
	 * filter()
	 *
	 * @param array $anchor
	 * @return anchor $anchor
	 **/

	function filter($anchor) {
		if ( preg_match("/\.(?:jpe?g|gif|png|bmp|webp)\b/i", $anchor['attr']['href']) )
			return auto_thickbox::image($anchor);
		elseif ( !empty($anchor['attr']['class']) && in_array('thickbox', $anchor['attr']['class']) )
			return auto_thickbox::iframe($anchor);
		else
			return $anchor;
	} # filter()
	
	
	/**
	 * image()
	 *
	 * @param array $anchor
	 * @return anchor $anchor
	 **/

	function image($anchor) {
		if ( $this->options['thickbox_text'] == 'manual' && !preg_match("/^\s*<\s*img\s.+?>\s*$/is", $anchor['body']) )
			return $anchor;
		
		if ( !$anchor['attr']['class'] ) {
			$anchor['attr']['class'][] = 'thickbox';
			$anchor['attr']['class'][] = 'no_icon';
		} else {
			if ( !in_array('thickbox', $anchor['attr']['class']) && !in_array('nothickbox', $anchor['attr']['class']) && !in_array('no_thickbox', $anchor['attr']['class']) )
				$anchor['attr']['class'][] = 'thickbox';
			if ( !in_array('no_icon', $anchor['attr']['class']) && !in_array('noicon', $anchor['attr']['class']) )
				$anchor['attr']['class'][] = 'no_icon';
		}
		
		if ( $this->options['thickbox_style'] == 'gallery' && in_the_loop() && !$anchor['attr']['rel'] )
			$anchor['attr']['rel'][] = 'gallery-' . get_the_ID();
		
		if ( empty($anchor['attr']['title']) ) {
			if ( preg_match("/\b(?:alt|title)\s*=\s*('|\")(.*?)\\1/i", $anchor['body'], $title) ) {
				$anchor['attr']['title'] = end($title);
			}
		}
		
		return $anchor;
	} # image()
	
	
	/**
	 * iframe()
	 *
	 * @return void
	 **/
	
	function iframe($anchor) {
		if ( strpos($anchor['attr']['href'], 'TB_iframe=true') !== false || strpos($anchor['attr']['href'], '#TB_inline') !== false )
			return $anchor;
		if ( strpos($anchor['attr']['href'], '://') === false || strpos($anchor['attr']['href'], $_SERVER['HTTP_HOST']) !== false )
			return $anchor; // not append 'TB_iframe=true' to URL in the same domain (i.e. display as not iframe but AJAX content)
		
		# strip anchor ref
		$href = explode('#', $anchor['attr']['href']);
		$anchor['attr']['href'] = array_shift($href);
		
		$anchor['attr']['href'] .= ( ( strpos($anchor['attr']['href'], '?') === false ) ? '?' : '&' )
			. 'TB_iframe=true' . ( count($href) == 0 ? '' : '#' . implode('#', $href) );
		
		return $anchor;
	} # iframe()
	
	
	/**
	 * scripts()
	 *
	 * @return void
	 **/

	function scripts() {
		if ( $this->options['thickbox_res'] == 'load' ) {
			wp_deregister_script('thickbox');
			wp_register_script('thickbox', plugins_url('thickbox.js', __FILE__), array('jquery'), AUTO_THICKBOX_PLUS_VERSION, true);
		}
		wp_enqueue_script('thickbox');
		wp_localize_script('thickbox', 'thickboxL10n', array(
			'next' => __('Next &gt;', 'auto-thickbox'),
			'prev' => __('&lt; Prev', 'auto-thickbox'),
			'image' => __('Image', 'auto-thickbox'),
			'of' => __('of', 'auto-thickbox'),
			'close' => __('Close', 'auto-thickbox'),
			'l10n_print_after' => 'try{convertEntities(thickboxL10n);}catch(e){};'
		));
	} # scripts()
	
	
	/**
	 * styles()
	 *
	 * @return void
	 **/

	function styles() {
		if ( $this->options['thickbox_res'] == 'load' ) {
			wp_deregister_style('thickbox');
			wp_register_style('thickbox', plugins_url('thickbox.css', __FILE__), false, AUTO_THICKBOX_PLUS_VERSION);
		}
		wp_enqueue_style('thickbox');
	} # styles()
	
	
	/**
	 * thickbox_images()
	 *
	 * @return void
	 **/

	function thickbox_images() {
		$includes_url = includes_url();
		
		echo <<<EOS

<script type="text/javascript">
var tb_pathToImage = "{$includes_url}js/thickbox/loadingAnimation.gif";
var tb_closeImage = "{$includes_url}js/thickbox/tb-close.png";
</script>

EOS;

		echo '<style type="text/css">';
		if ( !$this->is_default_option('font_title') )
			echo "#TB_title { font-family:{$this->options['font_title']}; }\n";
		if ( !$this->is_default_option('font_cap') )
			echo "#TB_caption,#TB_secondLine { font-family:{$this->options['font_cap']}; }\n";
		if ( !$this->is_default_option('font_weight_title') )
			echo "#TB_title { font-weight:{$this->options['font_weight_title']}; }\n";
		if ( !$this->is_default_option('font_weight_cap') )
			echo "#TB_caption { font-weight:{$this->options['font_weight_cap']}; }\n";
		if ( !$this->is_default_option('color_title') )
			echo "#TB_title { color:{$this->options['color_title']}; }\n";
		if ( !$this->is_default_option('color_nav') )
			echo "#TB_secondLine,#TB_window a:link,#TB_window a:visited { color:{$this->options['color_nav']}; }\n";
		if ( !$this->is_default_option('color_cap') )
			echo "#TB_caption,#TB_window a:hover { color:{$this->options['color_cap']}; }\n"; // :hover must be placed after :link and :visited
		if ( !$this->is_default_option('bgcolor_title') )
			echo "#TB_title { background-color:{$this->options['bgcolor_title']}; }\n";
		if ( !$this->is_default_option('bgcolor_cap') )
			echo "#TB_caption { background-color:{$this->options['bgcolor_cap']}; margin:4px 0 0 15px; padding-top:5px; height:23px; -moz-border-radius:4px; -webkit-border-radius:4px; -khtml-border-radius:4px; border-radius:4px; }\n";
		if ( !$this->is_default_option('bgcolor_win') )
			echo "#TB_window { background-color:{$this->options['bgcolor_win']}; }\n";
		if ( !$this->is_default_option('bgcolor_bg') )
			echo ".TB_overlayBG { background-color:{$this->options['bgcolor_bg']}; }\n";
		if ( !$this->is_default_option('border_win') )
			echo "#TB_window { border:{$this->options['border_win']}; }\n";
		if ( !$this->is_default_option('border_img_tl') )
			echo "#TB_window img#TB_Image { border-top:{$this->options['border_img_tl']}; border-left:{$this->options['border_img_tl']}; }\n";
		if ( !$this->is_default_option('border_img_br') )
			echo "#TB_window img#TB_Image { border-bottom:{$this->options['border_img_br']}; border-right:{$this->options['border_img_br']}; }\n";
		if ( !$this->is_default_option('radius_win') )
			echo "#TB_window { -moz-border-radius:{$this->options['radius_win']}px; -webkit-border-radius:{$this->options['radius_win']}px; -khtml-border-radius:{$this->options['radius_win']}px; border-radius:{$this->options['radius_win']}px; }\n";
		if ( !$this->is_default_option('opacity_bg') ) {
			$opacity_bg100 = $this->options['opacity_bg'] * 100;
			echo ".TB_overlayBG { -ms-filter:\"progid:DXImageTransform.Microsoft.Alpha(Opacity={$opacity_bg100})\"; filter:alpha(opacity={$opacity_bg100}); -moz-opacity:{$this->options['opacity_bg']}; opacity:{$this->options['opacity_bg']}; }\n";
		}
		if ( !$this->is_default_option('box_shadow_win') )
			echo "#TB_window { -moz-box-shadow:{$this->options['box_shadow_win']}; -webkit-box-shadow:{$this->options['box_shadow_win']}; -khtml-box-shadow:{$this->options['box_shadow_win']}; box-shadow:{$this->options['box_shadow_win']}; }\n";
		if ( !$this->is_default_option('txt_shadow_title') )
			echo "#TB_title { text-shadow:{$this->options['txt_shadow_title']}; }\n";
		if ( !$this->is_default_option('txt_shadow_cap') )
			echo "#TB_caption { text-shadow:{$this->options['txt_shadow_cap']}; }\n";
		echo '</style>';
	} # thickbox_images()

	function is_default_option($name) {
		return $this->options[$name] == $this->options_def[$name];
	}

	// Auto Thickbox Plus Options
	function auto_thickbox_menu() {
		add_options_page(__('Auto Thickbox Plus Options', 'auto-thickbox'), 'Auto Thickbox Plus', 8, __FILE__, array(&$this, 'auto_thickbox_options'));
	}
	function auto_thickbox_options() {
?>
<div class="wrap">
	<?php screen_icon(); ?>
	<h2><?php _e('Auto Thickbox Plus Options', 'auto-thickbox'); ?></h2>
	<form method="post" action="options.php">
		<?php settings_fields( 'auto-thickbox-plus-options' ); ?>
		<h3><?php _e('General'); ?></h3>
		<table class="form-table">
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('Default Display Style', 'auto-thickbox'); ?></th>
				<td>
					<label><input type="radio" name="auto-thickbox-plus[thickbox_style]" value="single"<?php checked($this->options['thickbox_style'], 'single'); ?> />
						<?php _e('Single Image (explicitly specify a@rel attribute as needed)', 'auto-thickbox'); ?></label><br />
					<label><input type="radio" name="auto-thickbox-plus[thickbox_style]" value="gallery"<?php checked($this->options['thickbox_style'], 'gallery'); ?> />
						<?php _e('Gallery Images (automatically set a@rel attribute in \'gallery-id\' format)', 'auto-thickbox'); ?></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('ThickBox on Text Links', 'auto-thickbox'); ?></th>
				<td>
					<label><input type="radio" name="auto-thickbox-plus[thickbox_text]" value="auto"<?php checked($this->options['thickbox_text'], 'auto'); ?> />
						<?php _e('Auto (automatically set a@class=&quot;thickbox&quot;)', 'auto-thickbox'); ?></label><br />
					<label><input type="radio" name="auto-thickbox-plus[thickbox_text]" value="manual"<?php checked($this->options['thickbox_text'], 'manual'); ?> />
						<?php _e('Manual (explicitly specify a@class=&quot;thickbox&quot; as needed)', 'auto-thickbox'); ?></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('ThickBox Resources (JS, CSS)', 'auto-thickbox'); ?></th>
				<td>
					<label><input type="checkbox" name="auto-thickbox-plus[thickbox_res]" value="load"<?php checked($this->options['thickbox_res'], 'load'); ?> />
						<?php _e('Loads optimized (compressed &amp; tweaked) alternative resources (thickbox.js, thickbox.css)', 'auto-thickbox'); ?></label>
				</td>
			</tr>
		</table>
		<h3><?php _e('View'); ?></h3>
		<table class="form-table">
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('Font family'); ?></th>
				<th scope="row"><?php _e('Title'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[font_title]" value="<?php esc_attr_e($this->options['font_title']); ?>" size="40" /></label>
					<label><input type="checkbox" name="auto-thickbox-plus[font_weight_title]" value="bold"<?php checked($this->options['font_weight_title'], 'bold'); ?> /><?php _e('Bold'); ?></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"></th>
				<th scope="row"><?php _e('Caption'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[font_cap]" value="<?php esc_attr_e($this->options['font_cap']); ?>" size="40" /></label>
					<label><input type="checkbox" name="auto-thickbox-plus[font_weight_cap]" value="bold"<?php checked($this->options['font_weight_cap'], 'bold'); ?> /><?php _e('Bold'); ?></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('Text Color'); ?></th>
				<th scope="row"><?php _e('Title'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[color_title]" value="<?php echo $this->options['color_title']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"></th>
				<th scope="row"><?php _e('Caption'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[color_cap]" value="<?php echo $this->options['color_cap']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"></th>
				<th scope="row"><?php _e('Navigation'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[color_nav]" value="<?php echo $this->options['color_nav']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('Background Color'); ?></th>
				<th scope="row"><?php _e('Title'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[bgcolor_title]" value="<?php echo $this->options['bgcolor_title']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"></th>
				<th scope="row"><?php _e('Caption'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[bgcolor_cap]" value="<?php echo $this->options['bgcolor_cap']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"></th>
				<th scope="row"><?php _e('Window', 'auto-thickbox'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[bgcolor_win]" value="<?php echo $this->options['bgcolor_win']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"></th>
				<th scope="row"><?php _e('Background'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[bgcolor_bg]" value="<?php echo $this->options['bgcolor_bg']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('Border'); ?></th>
				<th scope="row"><?php _e('Window', 'auto-thickbox'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[border_win]" value="<?php echo $this->options['border_win']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"></th>
				<th scope="row"><?php _e('Image'); ?> (<?php _e('Top left'); ?>)</th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[border_img_tl]" value="<?php echo $this->options['border_img_tl']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"></th>
				<th scope="row"><?php _e('Image'); ?> (<?php _e('Bottom right'); ?>)</th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[border_img_br]" value="<?php echo $this->options['border_img_br']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('Border Radius', 'auto-thickbox'); ?></th>
				<th scope="row"><?php _e('Window', 'auto-thickbox'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[radius_win]" value="<?php echo $this->options['radius_win']; ?>" /> px</label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('Opacity', 'auto-thickbox'); ?></th>
				<th scope="row"><?php _e('Background'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[opacity_bg]" value="<?php echo $this->options['opacity_bg']; ?>" /> (0 - 1)</label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('Box Shadow', 'auto-thickbox'); ?></th>
				<th scope="row"><?php _e('Window', 'auto-thickbox'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[box_shadow_win]" value="<?php echo $this->options['box_shadow_win']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('Text Shadow', 'auto-thickbox'); ?></th>
				<th scope="row"><?php _e('Title'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[txt_shadow_title]" value="<?php echo $this->options['txt_shadow_title']; ?>" /></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"></th>
				<th scope="row"><?php _e('Caption'); ?></th>
				<td>
					<label><input type="text" name="auto-thickbox-plus[txt_shadow_cap]" value="<?php echo $this->options['txt_shadow_cap']; ?>" /></label>
				</td>
			</tr>
		</table>
		<p class="submit">
			<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
			<input type="submit" class="button-primary" value="<?php _e('Reset') ?>" name="reset" />
		</p>
	</form>
</div>
<?php
	}

	// Additional links on the Plugins page
	function add_auto_thickbox_links($links, $file) {
		if ( $file == plugin_basename(__FILE__) ) {
			$links[] = '<a href="http://wordpress.org/extend/plugins/auto-thickbox-plus/" target="_blank">' . __('Show Details') . '</a>';
			$links[] = '<a href="' . get_bloginfo('url') . '/wp-admin/options-general.php?page=' . $file .'">' . __('Settings') . '</a>';
			$links[] = '<a href="http://wordpress.org/tags/auto-thickbox-plus" target="_blank">' . __('Support', 'auto-thickbox') . '</a>';
			$links[] = '<a href="' . __('http://attosoft.info/blog/en/', 'auto-thickbox') . 'contact/" target="_blank">' . __('Contact Me', 'auto-thickbox') . '</a>';
			$links[] = '<a href="' . __('http://attosoft.info/blog/en/', 'auto-thickbox') . 'donate/" target="_blank">' . __('Donate', 'auto-thickbox') . '</a>';
		}
		return $links;
	}

	var $options = array();
	var $options_def = array();

	function auto_thickbox() {
		$this->__construct(); // for PHP4
	}

	function __construct() {
if ( !is_admin() && isset($_SERVER['HTTP_USER_AGENT']) &&
    	strpos($_SERVER['HTTP_USER_AGENT'], 'W3C_Validator') === false) {
	if ( !class_exists('anchor_utils') )
		include dirname(__FILE__) . '/anchor-utils/anchor-utils.php';
		
	add_action('wp_print_scripts', array(&$this, 'scripts'));
	add_action('wp_print_styles', array(&$this, 'styles'));
	
	add_action('wp_footer', array(&$this, 'thickbox_images'), 20);
	
	add_filter('filter_anchor', array(&$this, 'filter'));
}

if ( is_admin() ) {
	add_action('admin_menu', array(&$this, 'auto_thickbox_menu'));
	add_action('admin_init', array(&$this, 'register_options'));
	add_filter('plugin_row_meta', array(&$this, 'add_auto_thickbox_links'), 10, 2);
}

		$this->options_def = array(
			'thickbox_style' => 'single',
			'thickbox_text' => 'auto',
			'thickbox_res' => 'load',
			'font_title' => '"Lucida Grande", Verdana, Arial, sans-serif',
			'font_cap' => '"Lucida Grande", Verdana, Arial, sans-serif',
			'font_weight_title' => 'normal',
			'font_weight_cap' => 'normal',
			'color_title' => 'black',
			'color_cap' => 'black',
			'color_nav' => '#666',
			'bgcolor_title' => '#e8e8e8',
			'bgcolor_cap' => 'transparent',
			'bgcolor_win' => 'white',
			'bgcolor_bg' => 'black',
			'border_win' => '1px solid #555',
			'border_img_tl' => '1px solid #666',
			'border_img_br' => '1px solid #ccc',
			'radius_win' => '0',
			'opacity_bg' => '0.75',
			'box_shadow_win' => 'rgba(0,0,0,1) 0 4px 30px',
			'txt_shadow_title' => 'none',
			'txt_shadow_cap' => 'none'
		);
		$this->options = get_option('auto-thickbox-plus');
		$this->options = $this->options ? wp_parse_args($this->options, $this->options_def) : $this->options_def;

		// XXX: transition code for v0.5 or earlier
		$thickbox_style = get_option('thickbox_style');
		if ($thickbox_style) {
			$this->options['thickbox_style'] = $thickbox_style;
			delete_option('thickbox_style');
		}
		$thickbox_text = get_option('thickbox_text');
		if ($thickbox_text) {
			$this->options['thickbox_text'] = $thickbox_text;
			delete_option('thickbox_text');
		}
		$thickbox_res = get_option('thickbox_res');
		if ($thickbox_res) {
			$this->options['thickbox_res'] = $thickbox_res;
			delete_option('thickbox_res');
		}
	}

	function register_options() {
		register_setting( 'auto-thickbox-plus-options', 'auto-thickbox-plus', array(&$this, 'options_callback') );
	}

	function options_callback($options) {
		if (isset($_POST['reset'])) return $this->options_def;
		if (!isset($options['thickbox_res'])) $options['thickbox_res'] = 'unload';
		return $options;
	}
} # auto_thickbox

add_action('init', 'init_auto_thickbox');
function init_auto_thickbox() {
	new auto_thickbox();
}
?>